package cn.pluss.platform.mapper;

import cn.pluss.platform.entity.RegionCodeLs;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 银盛地区表 Mapper 接口
 * </p>
 *
 * @author Djh
 * @since 2021-07-24
 */
public interface RegionCodeLsMapper extends BaseMapper<RegionCodeLs> {

    /**
     * 获取银盛对应的地区信息
     * @param province  省
     * @param city      市
     * @param area      县区
     * @return  地区信息
     */
    RegionCodeLs selectRegionCode(@Param("province") String province, @Param("city") String city, @Param("area") String area);

    List<String> selectProvince();

    List<String> selectCity(@Param("provice") String provice);

    List<String> selectArea(@Param("province") String province, @Param("city") String city);
}
